from django.utils.functional import cached_property

from wagtail.wagtailcore.blocks import ChooserBlock


class EmbedVideoChooserBlock(ChooserBlock):
    @cached_property
    def target_model(self):
        from wagtail_embed_videos.models import get_embed_video_model
        return get_embed_video_model()

    @cached_property
    def widget(self):
        from wagtail_embed_videos.widgets import AdminEmbedVideoChooser
        return AdminEmbedVideoChooser

    def render_basic(self, value):
        if value:
            print value
            return value.thumbnail
        else:
            return ''



# coding: utf-8

from django import forms
from django.forms.models import modelform_factory

from wagtail.wagtailimages.edit_handlers import AdminImageChooser


def get_embed_video_form(model):
    if hasattr(model, 'admin_form_fields'):
        fields = model.admin_form_fields
    else:
        fields = '__all__'

    return modelform_factory(
        model,
        fields=fields,
        widgets={
            'thumbnail': AdminImageChooser,
        })


class EmbedVideoInsertionForm(forms.Form):
    alt_text = forms.CharField()



from __future__ import absolute_import, unicode_literals

from wagtail.wagtailadmin.edit_handlers import BaseChooserPanel
from .widgets import AdminEmbedVideoChooser


class BaseEmbedVideoChooserPanel(BaseChooserPanel):
    object_type_name = "embed_video"

    @classmethod
    def widget_overrides(cls):
        return {cls.field_name: AdminEmbedVideoChooser}


class EmbedVideoChooserPanel(object):
    def __init__(self, field_name):
        self.field_name = field_name

    def bind_to_model(self, model):
        return type(str('_EmbedVideoChooserPanel'), (BaseEmbedVideoChooserPanel,), {
            'model': model,
            'field_name': self.field_name,
        })



# coding: utf-8
from __future__ import unicode_literals

try:
    import urllib2
except ImportError:
    import urllib3

from taggit.managers import TaggableManager

from django.core.exceptions import ImproperlyConfigured
from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.utils.encoding import python_2_unicode_compatible
from django.core.urlresolvers import reverse
from django.core.files import File
from django.core.files.temp import NamedTemporaryFile

from wagtail.wagtailadmin.taggable import TagSearchable
from wagtail.wagtailadmin.utils import get_object_usage
from wagtail.wagtailsearch import index
from wagtail.wagtailimages.models import Image as WagtailImage

from embed_video.fields import EmbedVideoField
from embed_video.backends import detect_backend

from django.conf import settings
try:
    from django.apps import apps
    get_model = apps.get_model
except ImportError:
    from django.db.models.loading import get_model


def create_thumbnail(model_instance):
    # CREATING IMAGE FROM THUMBNAIL
    print(model_instance)
    backend = detect_backend(model_instance.url)
    thumbnail_url = backend.get_thumbnail_url()

    img_temp = NamedTemporaryFile(delete=True)
    try:
        img_temp.write(urllib2.urlopen(thumbnail_url).read())
    except:
        http = urllib3.PoolManager()
        img_temp.write(http.request('GET', thumbnail_url).data)
    img_temp.flush()

    image = WagtailImage(title=model_instance.title)
    image.file.save(model_instance.title + '.jpg', File(img_temp))

    model_instance.thumbnail = image
    model_instance.thumbnail.tags.add('video-thumbnail')
    model_instance.save()


@python_2_unicode_compatible
class AbstractEmbedVideo(models.Model, TagSearchable):
    title = models.CharField(max_length=255, verbose_name=_('Title'))
    url = EmbedVideoField()
    thumbnail = models.ForeignKey(
        'wagtailimages.Image',
        verbose_name="Thumbnail",
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+'
    )
    created_at = models.DateTimeField(auto_now_add=True)
    uploaded_by_user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True, editable=False)

    tags = TaggableManager(help_text=None, blank=True, verbose_name=_('Tags'))

    def get_usage(self):
        return get_object_usage(self)

    @property
    def usage_url(self):
        return reverse('wagtail_embed_videos_video_usage',
                       args=(self.id,))

    search_fields = TagSearchable.search_fields + (
        index.FilterField('uploaded_by_user'),
    )

    def __str__(self):
        return self.title

    def __init__(self, *args, **kwargs):

        super(AbstractEmbedVideo, self).__init__(*args, **kwargs)
        if args:
            if args[3] is None:
                create_thumbnail(self)

    def save(self, *args, **kwargs):
        super(AbstractEmbedVideo, self).save(*args, **kwargs)
        if not self.thumbnail:
            create_thumbnail(self)
    
    @property
    def default_alt_text(self):
        return self.title

    def is_editable_by_user(self, user):
        if user.has_perm('wagtail_embed_videos.change_embedvideo'):
            # user has global permission to change videos
            return True
        elif user.has_perm('wagtail_embed_videos.add_embedvideo') and self.uploaded_by_user == user:
            # user has video add permission, which also implicitly provides permission to edit their own videos
            return True
        else:
            return False

    class Meta:
        abstract = True


class EmbedVideo(AbstractEmbedVideo):
    admin_form_fields = (
        'title',
        'url',
        'thumbnail',
        'tags',
    )


def get_embed_video_model():
    try:
        app_label, model_name = settings.WAGTAILEMBEDVIDEO_VIDEO_MODEL.split('.')
    except AttributeError:
        return EmbedVideo
    except ValueError:
        raise ImproperlyConfigured("WAGTAILEMBEDVIDEO_VIDEO_MODEL must be of the form 'app_label.model_name'")

    embed_video_model = get_model(app_label, model_name)
    if embed_video_model is None:
        raise ImproperlyConfigured("WAGTAILEMBEDVIDEO_VIDEO_MODEL refers to model '%s' that has not been installed" % settings.WAGTAILEMBEDVIDEO_VIDE_MODEL)
    return embed_video_model



from django.conf.urls import url

from wagtail_embed_videos.views import embed_videos, chooser


urlpatterns = [
    url(r'^$', embed_videos.index, name='wagtail_embed_videos_index'),
    url(r'^(\d+)/$', embed_videos.edit, name='wagtail_embed_videos_edit_embed_video'),
    url(r'^(\d+)/delete/$', embed_videos.delete, name='wagtail_embed_videos_delete_embed_video'),
    url(r'^(\d+)/preview/(.*)/$', embed_videos.preview, name='wagtail_embed_videos_preview'),
    url(r'^add/$', embed_videos.add, name='wagtail_embed_videos_add_embed_video'),
    url(r'^usage/(\d+)/$', embed_videos.usage, name='wagtail_embed_videos_video_usage'),

    url(r'^chooser/$', chooser.chooser, name='wagtail_embed_videos_chooser'),
    url(r'^chooser/(\d+)/$', chooser.embed_video_chosen, name='wagtail_embed_videos_embed_video_chosen'),
    # url(r'^chooser/upload/$', chooser.chooser_upload, name='wagtail_embed_videos_chooser_upload'),
    # url(r'^chooser/(\d+)/select_format/$', chooser.chooser_select_format, name='wagtail_embed_videos_chooser_select_format'),
]



import json

from django.shortcuts import render, redirect, get_object_or_404
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
from django.contrib.auth.decorators import permission_required
from django.core.exceptions import PermissionDenied
from django.utils.translation import ugettext as _
from django.views.decorators.vary import vary_on_headers
from django.core.urlresolvers import reverse
from django.http import HttpResponse

from wagtail.wagtailadmin.forms import SearchForm
from wagtail.wagtailadmin import messages
from wagtail.wagtailsearch.backends import get_search_backends

from wagtail_embed_videos.models import get_embed_video_model
from wagtail_embed_videos.forms import get_embed_video_form


@permission_required('wagtail_embed_videos.add_embedvideo')
@vary_on_headers('X-Requested-With')
def index(request):
    EmbedVideo = get_embed_video_model()

    # Get embed videos
    embed_videos = EmbedVideo.objects.order_by('-created_at')

    # Permissions
    if not request.user.has_perm('wagtail_embed_videos.change_embedvideo'):
        # restrict to the user's own embed videos
        embed_videos = embed_videos.filter(uploaded_by_user=request.user)

    # Search
    query_string = None
    if 'q' in request.GET:
        form = SearchForm(request.GET, placeholder=_("Search videos"))
        if form.is_valid():
            query_string = form.cleaned_data['q']

            if not request.user.has_perm(
                'wagtail_embed_videos.change_embedvideo'
            ):
                # restrict to the user's own embed videos
                embed_videos = EmbedVideo.search(
                    query_string,
                    filters={'uploaded_by_user_id': request.user.id}
                )
            else:
                embed_videos = EmbedVideo.search(query_string)
    else:
        form = SearchForm(placeholder=_("Search videos"))

    # Pagination
    p = request.GET.get('p', 1)
    paginator = Paginator(embed_videos, 20)

    try:
        embed_videos = paginator.page(p)
    except PageNotAnInteger:
        embed_videos = paginator.page(1)
    except EmptyPage:
        embed_videos = paginator.page(paginator.num_pages)

    # Create response
    if request.is_ajax():
        return render(
            request,
            'wagtail_embed_videos/embed_videos/results.html',
            {
                'embed_videos': embed_videos,
                'query_string': query_string,
                'is_searching': bool(query_string),
            }
        )
    else:
        return render(
            request,
            'wagtail_embed_videos/embed_videos/index.html',
            {
                'embed_videos': embed_videos,
                'query_string': query_string,
                'is_searching': bool(query_string),
                'search_form': form,
                'popular_tags': EmbedVideo.popular_tags(),
            }
        )


def edit(request, embed_video_id):
    EmbedVideo = get_embed_video_model()
    EmbedVideoForm = get_embed_video_form(EmbedVideo)

    embed_video = get_object_or_404(EmbedVideo, id=embed_video_id)

    if not embed_video.is_editable_by_user(request.user):
        raise PermissionDenied

    if request.POST:
        form = EmbedVideoForm(request.POST, request.FILES, instance=embed_video)
        if form.is_valid():
            form.save()

            # Reindex the embed_video to make sure all tags are indexed
            for backend in get_search_backends():
                backend.add(embed_video)

            messages.success(request, _("Video '{0}' updated.").format(embed_video.title), buttons=[
                messages.button(reverse('wagtail_embed_videos_edit_embed_video', args=(embed_video.id,)), _('Edit again'))
            ])
            return redirect('wagtail_embed_videos_index')
        else:
            messages.error(request, _("The video could not be saved due to errors."))
    else:
        form = EmbedVideoForm(instance=embed_video)

    return render(request, "wagtail_embed_videos/embed_videos/edit.html", {
        'embed_video': embed_video,
        'form': form,
    })


def json_response(document, status=200):
    return HttpResponse(json.dumps(document), content_type='application/json', status=status)


def preview(request, embed_video_id):
    embed_video = get_object_or_404(get_embed_video_model(), id=embed_video_id)

    return HttpResponse({'embed_video_preview': embed_video.url.thumbnail}, content_type='image/jpeg')


def delete(request, embed_video_id):
    embed_video = get_object_or_404(get_embed_video_model(), id=embed_video_id)

    if not embed_video.is_editable_by_user(request.user):
        raise PermissionDenied

    if request.POST:
        embed_video.delete()
        messages.success(request, _("Video '{0}' deleted.").format(embed_video.title))
        return redirect('wagtail_embed_videos_index')

    return render(request, "wagtail_embed_videos/embed_videos/confirm_delete.html", {
        'embed_video': embed_video,
    })


@permission_required('wagtail_embed_videos.add_embedvideo')
def add(request):
    EmbedVideoModel = get_embed_video_model()
    EmbedVideoForm = get_embed_video_form(EmbedVideoModel)

    if request.POST:
        embed_video = EmbedVideoModel(uploaded_by_user=request.user)
        form = EmbedVideoForm(request.POST, request.FILES, instance=embed_video)
        if form.is_valid():
            form.save()

            # Reindex the embed video to make sure all tags are indexed
            for backend in get_search_backends():
                backend.add(embed_video)

            messages.success(request, _("Video '{0}' added.").format(embed_video.title), buttons=[
                messages.button(reverse('wagtail_embed_videos_edit_embed_video', args=(embed_video.id,)), _('Edit'))
            ])
            return redirect('wagtail_embed_videos_index')
        else:
            messages.error(request, _("The video could not be created due to errors."))
    else:
        form = EmbedVideoForm()

    return render(request, "wagtail_embed_videos/embed_videos/add.html", {
        'form': form,
    })


def usage(request, embed_video_id):
    embed_video = get_object_or_404(get_embed_video_model(), id=embed_video_id)

    # Pagination
    p = request.GET.get('p', 1)
    paginator = Paginator(embed_video.get_usage(), 20)

    try:
        used_by = paginator.page(p)
    except PageNotAnInteger:
        used_by = paginator.page(1)
    except EmptyPage:
        used_by = paginator.page(paginator.num_pages)

    return render(request, "wagtail_embed_videos/embed_videos/usage.html", {
        'embed_video': embed_video,
        'used_by': used_by
    })



import json

from django.core.urlresolvers import reverse
from django.shortcuts import get_object_or_404, render
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
from django.contrib.auth.decorators import permission_required

from wagtail.wagtailadmin.modal_workflow import render_modal_workflow
from wagtail.wagtailadmin.forms import SearchForm
from wagtail.wagtailsearch.backends import get_search_backends

from embed_video.backends import detect_backend

from wagtail_embed_videos.models import get_embed_video_model
from wagtail_embed_videos.forms import get_embed_video_form, EmbedVideoInsertionForm
# from wagtail_embed_videos.formats import get_embed_video_format


def get_embed_video_json(embed_video):
    """
    helper function: given an embed video, return the json to pass back to the
    embed video chooser panel
    """
    if embed_video.thumbnail:
        preview_embed_video = embed_video.thumbnail.get_rendition('max-130x100').url
    else:
        preview_embed_video = detect_backend(embed_video.url).get_thumbnail_url()

    return json.dumps({
        'id': embed_video.id,
        'edit_link': reverse('wagtail_embed_videos_edit_embed_video', args=(embed_video.id,)),
        'title': embed_video.title,
        'preview': {
            'url': preview_embed_video,
        }
    })


def chooser(request):
    EmbedVideo = get_embed_video_model()

    if request.user.has_perm('wagtail_embed_videos.add_embedvideo'):
        can_add = True
    else:
        can_add = False

    q = None
    if 'q' in request.GET or 'p' in request.GET:
        searchform = SearchForm(request.GET)
        if searchform.is_valid():
            q = searchform.cleaned_data['q']

            # page number
            p = request.GET.get("p", 1)

            embed_videos = EmbedVideo.search(q, results_per_page=10, page=p)

            is_searching = True

        else:
            embed_videos = EmbedVideo.objects.order_by('-created_at')
            p = request.GET.get("p", 1)
            paginator = Paginator(embed_videos, 10)

            try:
                embed_videos = paginator.page(p)
            except PageNotAnInteger:
                embed_videos = paginator.page(1)
            except EmptyPage:
                embed_videos = paginator.page(paginator.num_pages)

            is_searching = False
        return render(request, "wagtail_embed_videos/chooser/results.html", {
            'embed_videos': embed_videos,
            'is_searching': is_searching,
            'can_add': can_add,
            'query_string': q,
        })
    else:
        searchform = SearchForm()

        embed_videos = EmbedVideo.objects.order_by('-created_at')
        p = request.GET.get("p", 1)
        paginator = Paginator(embed_videos, 10)

        try:
            embed_videos = paginator.page(p)
        except PageNotAnInteger:
            embed_videos = paginator.page(1)
        except EmptyPage:
            embed_videos = paginator.page(paginator.num_pages)
    print(can_add)
    return render_modal_workflow(
        request,
        'wagtail_embed_videos/chooser/chooser.html',
        'wagtail_embed_videos/chooser/chooser.js',
        {
            'embed_videos': embed_videos,
            'searchform': searchform,
            'is_searching': False,
            'can_add': can_add,
            'query_string': q,
            'popular_tags': EmbedVideo.popular_tags(),
        }
    )


def embed_video_chosen(request, embed_video_id):
    embed_video = get_object_or_404(get_embed_video_model(), id=embed_video_id)

    return render_modal_workflow(
        request, None, 'wagtail_embed_videos/chooser/embed_video_chosen.js',
        {'embed_video_json': get_embed_video_json(embed_video)}
    )


# @permission_required('wagtail_embed_videos.add_embedvideo')
# def chooser_upload(request):
#     EmbedVideo = get_embed_video_model()
#     EmbedVideoForm = get_embed_video_form(EmbedVideo)

#     searchform = SearchForm()

#     if request.POST:
#         embed_video = EmbedVideo(uploaded_by_user=request.user)
#         form = EmbedVideoForm(request.POST, request.FILES, instance=embed_video)

#         if form.is_valid():
#             form.save()

#             # Reindex the embed video to make sure all tags are indexed
#             for backend in get_search_backends():
#                 backend.add(embed_video)

#             if request.GET.get('select_format'):
#                 form = EmbedVideoInsertionForm(initial={'alt_text': embed_video.default_alt_text})
#                 return render_modal_workflow(
#                     request, 'wagtail_embed_videos/chooser/select_format.html', 'wagtail_embed_videos/chooser/select_format.js',
#                     {'embed_video': embed_video, 'form': form}
#                 )
#             else:
#                 # not specifying a format; return the embed video details now
#                 return render_modal_workflow(
#                     request, None, 'wagtail_embed_videos/chooser/embed_video_chosen.js',
#                     {'embed_video_json': get_embed_video_json(embed_video)}
#                 )
#     else:
#         form = EmbedVideoForm()

#     embed_videos = EmbedVideo.objects.order_by('title')

#     return render_modal_workflow(
#         request, 'wagtail_embed_videos/chooser/chooser.html', 'wagtail_embed_videos/chooser/chooser.js',
#         {'embed_videos': embed_videos, 'uploadform': form, 'searchform': searchform}
#     )


# def chooser_select_format(request, embed_video_id):
#     embed_video = get_object_or_404(get_embed_video_model(), id=embed_video_id)

#     if request.POST:
#         form = EmbedVideoInsertionForm(request.POST, initial={'alt_text': embed_video.default_alt_text})
#         if form.is_valid():

#             preview_embed_video = detect_backend(embed_video.url).get_thumbnail_url()

#             embed_video_json = json.dumps({
#                 'id': embed_video.id,
#                 'title': embed_video.title,
#                 'format': format.name,
#                 'alt': form.cleaned_data['alt_text'],
#                 'class': format.classnames,
#                 'edit_link': reverse('wagtail_embed_videos_edit_embed_video', args=(embed_video.id,)),
#                 'preview': {
#                     'url': preview_embed_video,
#                 },
#                 'html': format.embed_video_to_editor_html(embed_video, form.cleaned_data['alt_text']),
#             })

#             return render_modal_workflow(
#                 request, None, 'wagtail_embed_videos/chooser/embed_video_chosen.js',
#                 {'embed_video_json': embed_video_json}
#             )
#     else:
#         form = EmbedVideoInsertionForm(initial={'alt_text': embed_video.default_alt_text})

#     return render_modal_workflow(
#         request, 'wagtail_embed_videos/chooser/select_format.html', 'wagtail_embed_videos/chooser/select_format.js',
#         {'embed_video': embed_video, 'form': form}
#     )



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import embed_video.fields
import wagtail.wagtailadmin.taggable
import django.db.models.deletion
from django.conf import settings
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0001_initial'),
        ('wagtailimages', '0006_add_verbose_names'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='EmbedVideo',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('title', models.CharField(max_length=255, verbose_name='Title')),
                ('url', embed_video.fields.EmbedVideoField()),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('tags', taggit.managers.TaggableManager(to='taggit.Tag', through='taggit.TaggedItem', blank=True, help_text=None, verbose_name='Tags')),
                ('thumbnail', models.ForeignKey(related_name='+', on_delete=django.db.models.deletion.SET_NULL, verbose_name='Thumbnail', blank=True, to='wagtailimages.Image', null=True)),
                ('uploaded_by_user', models.ForeignKey(blank=True, editable=False, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'abstract': False,
            },
            bases=(models.Model, wagtail.wagtailadmin.taggable.TagSearchable),
        ),
    ]



from django.conf import settings
from django.conf.urls import include, url
from django.core import urlresolvers
from django.utils.html import format_html, format_html_join
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import Permission
from django.contrib.contenttypes.models import ContentType

from wagtail.wagtailcore import hooks
from wagtail.wagtailadmin.menu import MenuItem

from wagtail_embed_videos import admin_urls


@hooks.register('register_admin_urls')
def register_admin_urls():
    return [
        url(r'^embed_videos/', include(admin_urls)),
    ]


@hooks.register('construct_main_menu')
def construct_main_menu(request, menu_items):
    pass


class EmbedVideosMenuItem(MenuItem):
    def is_shown(self, request):
        return request.user.has_perm('wagtail_embed_videos.add_embedvideo')


@hooks.register('register_admin_menu_item')
def register_embed_videos_menu_item():
    return EmbedVideosMenuItem(
        _('Embed Videos'),
        urlresolvers.reverse('wagtail_embed_videos_index'),
        classnames='icon icon-media', order=301)


@hooks.register('insert_editor_js')
def editor_js():
    js_files = [
        'wagtail_embed_videos/js/embed-video-chooser.js',
    ]
    js_includes = format_html_join('\n', '<script src="{0}{1}"></script>', (
        (settings.STATIC_URL, filename) for filename in js_files)
    )
    return js_includes + format_html(
        """
        <script>
            window.chooserUrls.embedVideoChooser = '{0}';
        </script>
        """,
        urlresolvers.reverse('wagtail_embed_videos_chooser')
    )


@hooks.register('register_permissions')
def register_permissions():
    embed_video_content_type = ContentType.objects.get(
        app_label='wagtail_embed_videos', model='embedvideo')
    embed_video_permissions = Permission.objects.filter(
        content_type=embed_video_content_type)
    return embed_video_permissions



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_embed_videos', '0002_auto_20150720_1137'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='embedvideo',
            options={},
        ),
        migrations.AlterField(
            model_name='embedvideo',
            name='thumbnail',
            field=models.ForeignKey(related_name='+', on_delete=django.db.models.deletion.SET_NULL, verbose_name='Thumbnail', blank=True, to='wagtailimages.Image', null=True),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='embedvideo',
            name='title',
            field=models.CharField(max_length=255, verbose_name='Title'),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtail_embed_videos', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='embedvideo',
            options={'verbose_name': 'V\xeddeo', 'verbose_name_plural': 'V\xeddeos'},
        ),
        migrations.AlterField(
            model_name='embedvideo',
            name='thumbnail',
            field=models.ForeignKey(related_name='+', on_delete=django.db.models.deletion.SET_NULL, verbose_name='Miniatura', blank=True, to='wagtailimages.Image', null=True),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='embedvideo',
            name='title',
            field=models.CharField(max_length=255, verbose_name='T\xedtulo'),
            preserve_default=True,
        ),
    ]



#!/usr/bin/env python
from distutils.core import setup


setup(
    name='wagtail_embed_videos',
    version='0.2',
    description='Embed Videos for Wagtail CMS.',
    long_description=(
        "Simple app that works similar to wagtailimages,"
        "but for embedding YouTube and Vimeo videos and music from SoundCloud."
        "It's an integration of django-embed-video."
        ),
    author='Diogo Marques',
    author_email='doriva.marques.29@gmail.com',
    maintainer='Diogo Marques',
    maintainer_email='doriva.marques.29@gmail.com',
    url='https://github.com/infoportugal/wagtail-embedvideos',
    packages=[
        'wagtail_embed_videos',
        'wagtail_embed_videos.views',
        'wagtail_embed_videos.migrations'],
    package_data={
        'wagtail_embed_videos': [
            'static/wagtail_embed_videos/js/*.js',
            'templates/wagtail_embed_videos/chooser/*.html',
            'templates/wagtail_embed_videos/edit_handlers/*.html',
            'templates/wagtail_embed_videos/embed_videos/*.html',
            'templates/wagtail_embed_videos/widgets/*.html',
            'templates/wagtail_embed_videos/chooser/*.js',
            'templates/wagtail_embed_videos/edit_handlers/*.js',
            'templates/wagtail_embed_videos/embed_videos/*.js',
            'templates/wagtail_embed_videos/widgets/*.js',
        ]
    },
    install_requires=[
        'django>=1.7',
        'wagtail>=1.0',
        'django-embed-video>=1.0'],
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Operating System :: OS Independent',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Framework :: Django',
        'License :: OSI Approved :: BSD License'],
    license='New BSD',

)
